FritzApiClient class abstract

Constructors

FritzApiClient({String baseUrl = 'http://fritz.box'})

Properties

baseUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
A 64-bit number represented by 16 hex digits. It is assigned at login and must be kept for the duration of the session. A program should only use one FRITZ!Box should only use one session ID for each FRITZ!Box, as the number of sessions for a FRITZ!Box is limited. FRITZ!Box is limited.
getter/setter pair

Methods

get(Uri url, {Map<String, String>? headers}) → Future<FritzApiResponse>
getDevices() → Future<Devices>
getEnergyStats({required HomeAutoQueryCommand command, required int deviceId}) → Future<EnergyStats?>
http://fritz.box/net/home_auto_query.lua ?sid=
getSessionId({String? username, required String password}) → Future<String?>
isConnectedWithFritzBox() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(Uri url, {Map<String, String>? headers, required Map<String, String> body}) → Future<FritzApiResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited